==> v8.3.zip: ru_twords_ru_tw/bible/kt/body.md <==
# тело, тела

## Определение:

Слово “тело” означает физическое тело человека или животного. Оно используется также в переносном значении обозначая какой-либо предмет или группу предметов.

* Слово “тело” может обозначать труп человека или животного.
* Когда Иисус на Своей последней пасхальной вечере взял хлеб, Он сказал ученикам: “Это — Моё тело”. Иисус имел в виду Своё физическое тело, приносимое в жертву за наши грехи.
* В Библии христиане, как Божий народ, названы “Телом Христа”.
* “Тело Христа” состоит из многих отдельных членов подобно тому, как физическое тело состоит из многих частей.
* Каждый верующий выполняет особую функцию в “Теле Христа”, чтобы все вместе служили Богу и приносили Ему славу.
* Иисуса также называют “Главой Тела”, состоящего из верующих в Него. Подобно тому как голова человека управляет всем телом, так и Иисус ведёт и направляет христиан как членов Своего Тела.

## Варианты перевода:

* Это слово лучше всего переводить словом, которым в целевом языке обычно обозначается физическое тело человека. Убедитесь в том, что используемое вами слово не имеет оскорбительного смысла или оттенка.
* В некоторых языках по отношению ко всем верующим можно использовать фразу “духовное Тело Христа”.
* Слова Иисуса “Это Моё тело” лучше всего перевести буквально. При необходимости можно добавить пояснение в примечании.
* В некоторых языках может быть отдельное слово для обозначения мёртвого тела (например, “труп” — о человеке; “туша” — о животном). Убедитесь в том, что слово, используемое вами в переводе, верно передаёт значение контекста и является приемлемым.

(См. также: [голова](../other/head.md), [дух](../kt/spirit.md))

## Ссылки на библейский текст:

* [1 Пар. 10:11-12](rc://*/tn/help/1ch/10/11)
* [1 Кор. 5:3-5](rc://*/tn/help/1co/05/03)
* [Еф. 4:4-6](rc://*/tn/help/eph/04/04)
* [Judges 14:7-9](rc://*/tn/help/jdg/14/07)
* [Чис. 6:6-8](rc://*/tn/help/num/06/06)
* [Пс. 31:8-9](rc://*/tn/help/psa/031/008)
* [Рим. 12:4-5](rc://*/tn/help/rom/12/04)

## Данные о слове:

* Номера Стронга: H990, H1320, H1460, H1465, H1472, H1480, H1655, H3409, H4191, H5038, H5085, H5315, H6106, H6297, H7607, G4430, G4954, G4983, G5559

==> v9.2.zip: ru_twords_ru_tw/bible/kt/body.md <==
# тело, телесное

## Определение:

Слово “тело” означает физическое тело человека или животного. Это слово иногда используется в переносном значении, для обозначения группы людей, чтобы подчеркнуть тесную взаимосвязь между этими людьми. Прилагательное "телесный" означает "физический", "материальный"; иногда оно может иметь негативное значение - как противопоставление духовному, божественному.
* Слово “тело” может обозначать труп человека или животного.
* Когда Иисус на Своей последней пасхальной вечере взял хлеб, Он сказал ученикам: “Это — Моё тело”. Иисус имел в виду Своё физическое тело, приносимое в жертву за наши грехи.
* В Библии христиане, как Божий народ, названы “Телом Христа”.
* “Тело Христа” состоит из многих отдельных членов подобно тому, как физическое тело состоит из многих частей.
* Каждый верующий выполняет особую функцию в “Теле Христа”, чтобы все вместе служили Богу и приносили Ему славу.
* Иисуса также называют “Главой Тела”, состоящего из верующих в Него. Подобно тому как голова человека управляет всем телом, так и Иисус ведёт и направляет христиан как членов Своего Тела.

## Варианты перевода:

* Это слово лучше всего переводить словом, которым в целевом языке обычно обозначается физическое тело человека. Убедитесь в том, что используемое вами слово не имеет оскорбительного смысла или оттенка.
* В некоторых языках по отношению ко всем верующим можно использовать фразу “духовное Тело Христа”.
* Слова Иисуса “Это Моё тело” лучше всего перевести буквально. При необходимости можно добавить пояснение в примечании.
* В некоторых языках может быть отдельное слово для обозначения мёртвого тела (например, “труп” — о человеке; “туша” — о животном). Убедитесь в том, что слово, используемое вами в переводе, верно передаёт значение контекста и является приемлемым.
* Словосочетание "телесное упражнение" означает "физические упражнения, занятия спортом".

(См. также: [голова](../other/head.md), [дух](../kt/spirit.md))

## Ссылки на библейский текст:

* [1 Пар. 10:11-12](rc://ru/tn/help/1ch/10/11)
* [1 Кор. 5:3-5](rc://ru/tn/help/1co/05/03)
* [Еф. 4:4-6](rc://ru/tn/help/eph/04/04)
* [Judges 14:7-9](rc://ru/tn/help/jdg/14/07)
* [Чис. 6:6-8](rc://ru/tn/help/num/06/06)
* [Пс. 31:8-9](rc://ru/tn/help/psa/031/008)
* [Рим. 12:4-5](rc://ru/tn/help/rom/12/04)


## Данные о слове:

* Номера Стронга: H990, H1320, H1460, H1465, H1472, H1480, H1655, H3409, H4191, H5038, H5085, H5315, H6106, H6297, H7607, G4430, G4954, G4983, G5559
